@@ -1,7 +1,7 @@
 from django.core.validators import RegexValidator
 from django.forms import (
     CharField,
-    BooleanField, PasswordInput,
+    BooleanField, PasswordInput, ModelChoiceField,
 )
 
 from ipam.models import IPAddress, Prefix
@@ -32,9 +32,9 @@ class AppEnvironmentForm(NetBoxModelForm):
         label="OCP Project",
         help_text="Choose the ocp project e.g. web shop",
     )
-    egress_ip = DynamicModelChoiceField(
-        # queryset=Prefix.get_child_ips(Prefix.objects.get(prefix='10.190.1.64/26')),
-        queryset=IPAddress.objects.filter(address__net_host_contained='10.190.1.64/26'),
+    egress_ip = ModelChoiceField(
+        queryset=Prefix.get_child_ips(Prefix.objects.get(prefix='10.190.1.64/26')),
+        #queryset=IPAddress.objects.filter(address__net_host_contained='10.190.1.64/26'),
         label="Egress IP",
         help_text="Select your egress ip",
     )
